### Name: findMaxTemper
### Title: Find the maximum temperature for parallel MCMC chains
### Aliases: findMaxTemper
### Keywords: methods

### ** Examples

## Not run: 
##D ## The following example is a simple stochastic optimization problem,
##D ## and thus it does not require any "heating up", and hence the
##D ## maximum temperature turns out to be the coldest one, i.e, 0.5.
##D adjMatSum <-
##D     function (xx)
##D {
##D     xx     <- as.integer(xx)
##D     adjMat <- outer(xx, xx, function (id1, id2) { id1 == id2 })
##D     sum(adjMat)
##D }
##D modeSensitive1 <-
##D     function (xx)
##D {
##D     with(partitionRep(xx),
##D      {
##D          rr   <- 1 + seq_along(clusterLabels)
##D          freq <- sapply(clusters, length)
##D          oo   <- order(freq, decreasing = TRUE)
##D          sum(sapply(clusters[oo], sum) * log(rr))
##D      })
##D }
##D entropy <-
##D     function (xx)
##D {
##D     yy <- table(as.vector(xx, mode = "numeric"))
##D     zz <- yy / length(xx)
##D     -sum(zz * log(zz))
##D }
##D maxProp <- 
##D     function (xx)
##D {
##D     yy <- table(as.vector(xx, mode = "numeric"))
##D     oo <- order(yy, decreasing = TRUE)
##D     yy[oo][1] / length(xx)
##D }
##D statsFuncList  <- list(adjMatSum, modeSensitive1, entropy, maxProp)
##D KMeansObj      <- KMeansFuncGenerator1(-97531)
##D maxTemperObj   <-
##D     with(KMeansObj,
##D      {
##D          temperLadder <- c(20, 10, 5, 1, 0.5)
##D          nLevels      <- length(temperLadder)
##D          sampDim      <- nrow(yy)
##D          startingVals <- sample(c(0, 1),
##D                                 size    = nLevels * sampDim,
##D                                 replace = TRUE)
##D          startingVals <- matrix(startingVals, nrow = nLevels, ncol = sampDim)
##D          findMaxTemper(nIters            = 5000,
##D                        statsFuncList     = statsFuncList,
##D                        temperLadder      = temperLadder,
##D                        startingVals      = startingVals,
##D                        logTarDensFunc    = logTarDensFunc,
##D                        levelsSaveSampFor = seq_len(nLevels),
##D                        doFullAnal        = TRUE,
##D                        saveFitness       = TRUE,
##D                        verboseLevel      = 1)
##D      })
##D print(maxTemperObj)
##D print(names(maxTemperObj))
##D with(c(maxTemperObj, KMeansObj),
##D  {
##D      fitnessCol <- ncol(draws[ , , 1])     
##D      sub        <- paste('uniform prior on # of clusters: DU[',
##D                          priorMinClusters, ', ',
##D                          priorMaxClusters, ']', sep = '')
##D      for (ii in rev(seq_along(levelsSaveSampFor))) {
##D          main <- paste('EMCC (MAP) clustering (temper = ',
##D                        round(temperLadder[levelsSaveSampFor[ii]], 3), ')',
##D                        sep = '')
##D          MAPRow <- which.min(draws[ , fitnessCol, ii])
##D          clusterPlot(clusterInd        = draws[MAPRow, -fitnessCol, ii],
##D                      data              = yy,
##D                      main              = main,
##D                      sub               = sub,
##D                      knownClusterMeans = knownClusterMeans)
##D      }
##D  })
## End(Not run)



